OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Mapa »config« nima določenih ustreznih dovoljenj za pisanje!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Napako je mogoče odpraviti z dodelitvijo dovoljenja spletnemu strežniku za pisanje v nastavitveno mapo.",
    "See %s" : "Oglejte si %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Napako je mogoče odpraviti z %sdodelitvijo dovoljenja spletnemu strežniku za pisanje v nastavitveno mapo%s.",
    "Sample configuration detected" : "Zaznana je neustrezna preizkusna nastavitev",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Zaznano je, da je bila v sistem kopirana datoteka z enostavno nastavitvijo. To lahko vpliva na namestitev in zato možnost ni podprta. Pred spremembami datoteke config.php si natančno preberite dokumentacijo.",
    "PHP %s or higher is required." : "Zahtevana je različica PHP %s ali višja.",
    "PHP with a version lower than %s is required." : "Zahtevana je različica PHP manj kot %s.",
    "%sbit or higher PHP required." : "Zahtevana je različica PHP %s ali višja.",
    "Following databases are supported: %s" : "Podprte so navedene podatkovne zbirke: %s",
    "The command line tool %s could not be found" : "Orodja ukazne vrstice %s ni mogoče najti",
    "The library %s is not available." : "Knjižnica %s ni na voljo.",
    "Library %s with a version higher than %s is required - available version %s." : "Zahtevana je knjižnica %s z različico, višjo od %s – na voljo je različica %s.",
    "Library %s with a version lower than %s is required - available version %s." : "Zahtevana je knjižnica %s z različico, manjšo od %s – na voljo je različica %s.",
    "Following platforms are supported: %s" : "Podprta so okolja: %s",
    "ownCloud %s or higher is required." : "Zahtevana je različica ownCloud %s ali višja.",
    "ownCloud %s or lower is required." : "Zahtevana je različica ownCloud %s ali nižja.",
    "Unknown filetype" : "Neznana vrsta datoteke",
    "Invalid image" : "Neveljavna slika",
    "Avatar image is not square" : "Sličica podobe uporabnika ni kvadratna",
    "today" : "danes",
    "yesterday" : "včeraj",
    "_%n day ago_::_%n days ago_" : ["pred %n dnevom","pred %n dnevoma","pred %n dnevi","pred %n dnevi"],
    "last month" : "zadnji mesec",
    "_%n month ago_::_%n months ago_" : ["pred %n mesecem","pred %n mesecema","pred %n meseci","pred %n meseci"],
    "last year" : "lansko leto",
    "_%n year ago_::_%n years ago_" : ["pred %n letom","pred %n letoma","pred %n leti","pred %n leti"],
    "_%n hour ago_::_%n hours ago_" : ["pred %n uro","pred %n urama","pred %n urami","pred %n urami"],
    "_%n minute ago_::_%n minutes ago_" : ["pred %n minuto","pred %n minutama","pred %n minutami","pred %n minutami"],
    "seconds ago" : "pred nekaj sekundami",
    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modul z id: %s ne obstaja. Omogočite ga, ali pa stopite v stik s skrbnikom sistema.",
    "Builtin" : "Vgrajeno",
    "None" : "Brez",
    "Username and password" : "Uporabniško ime in geslo",
    "Username" : "Uporabniško ime",
    "Password" : "Geslo",
    "Log-in credentials, save in session" : "Prijavna poverila, shrani v seji",
    "Empty filename is not allowed" : "Prazno polje imena datoteke ni dovoljeno.",
    "Dot files are not allowed" : "Skrite datoteke niso dovoljene",
    "4-byte characters are not supported in file names" : "4-bitni znaki v imenih datotek niso podprti",
    "File name is a reserved word" : "Ime datoteke je zadržana beseda",
    "File name contains at least one invalid character" : "Ime datoteke vsebuje vsaj en neveljaven znak.",
    "File name is too long" : "Ime datoteke je predolgo",
    "App directory already exists" : "Programska mapa že obstaja",
    "Can't create app folder. Please fix permissions. %s" : "Programske mape ni mogoče ustvariti. Ni ustreznih dovoljenj. %s",
    "Archive does not contain a directory named %s" : "V arhivu ni mape z imenom %s",
    "No source specified when installing app" : "Ni podanega vira med nameščenjem programa",
    "No href specified when installing app from http" : "Ni podanega podatka naslova HREF med nameščenjem programa prek protokola HTTP.",
    "No path specified when installing app from local file" : "Ni podane poti med nameščenjem programa iz krajevne datoteke",
    "Archives of type %s are not supported" : "Arhivi vrste %s niso podprti",
    "Failed to open archive when installing app" : "Odpiranje arhiva je med nameščanjem spodletelo",
    "App does not provide an info.xml file" : "Program je brez datoteke info.xml",
    "App cannot be installed because appinfo file cannot be read." : "Programa ni mogoče namestiti, ker ni mogoče brati datoteke appinfo.",
    "Signature could not get checked. Please contact the app developer and check your admin screen." : "Podpisa ni mogoče preveriti. Stopite v stik z razvijalci programa in preverite skrbniški dnevnik.",
    "App can't be installed because of not allowed code in the App" : "Programa ni mogoče namestiti zaradi nedovoljene programske kode.",
    "App can't be installed because it is not compatible with this version of ownCloud" : "Programa ni mogoče namestiti, ker ni skladen z trenutno nameščeno različico oblaka ownCloud.",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Programa ni mogoče namestiti, ker vsebuje oznako <shipped>potrditve</shipped>, ki pa ni dovoljena za javne programe.",
    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "Program ni mogoče namestiti zaradi neustrezne različice datoteke info.xml. Ta ni enaka različici programa.",
    "Apps" : "Programi",
    "General" : "Splošno",
    "Storage" : "Shramba",
    "Security" : "Varnost",
    "Encryption" : "Šifriranje",
    "Workflows & Tags" : "Potek dela in oznake",
    "Sharing" : "Souporaba",
    "Search" : "Poišči",
    "Updates" : "Posodobitve",
    "Help & Tips" : "Pomoč & Namigi",
    "Additional" : "Dodatno",
    "%s enter the database username and name." : "%s - vnos uporabniškega imena in imena podatkovne zbirke.",
    "%s enter the database username." : "%s - vnos uporabniškega imena podatkovne zbirke.",
    "%s enter the database name." : "%s - vnos imena podatkovne zbirke.",
    "%s you may not use dots in the database name" : "%s - v imenu podatkovne zbirke ni dovoljeno uporabljati pik.",
    "Oracle connection could not be established" : "Povezave s sistemom Oracle ni mogoče vzpostaviti.",
    "Oracle username and/or password not valid" : "Uporabniško ime ali geslo Oracle ni veljavno",
    "DB Error: \"%s\"" : "Napaka podatkovne zbirke: \"%s\"",
    "Offending command was: \"%s\"" : "Napačni ukaz je: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Prijaviti se je treba v obstoječi ali pa skrbniški račun.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Napačni ukaz je: \"%s\", ime: %s, geslo: %s",
    "PostgreSQL username and/or password not valid" : "Uporabniško ime ali geslo PostgreSQL ni veljavno",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Sistem Mac OS X ni podprt, zato %s v tem okolju ne bo deloval zanesljivo. Program uporabljate na lastno odgovornost! ",
    "For the best results, please consider using a GNU/Linux server instead." : "Za najbolj še rezultate je priporočljivo uporabljati strežnik GNU/Linux.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Videti je, da je dejavna seja %s zagnana v 32-bitnem okolju PHP in, da je v datoteki php.ini nastavljen open_basedir . Tako delovanje ni priporočljivo, saj se lahko pojavijo težave z datotekami, večjimi od 4GB.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Odstraniti je treba nastavitev open_basedir v datoteki php.ini ali pa preklopiti na 64-bitno okolje PHP.",
    "Set an admin username." : "Nastavi uporabniško ime skrbnika.",
    "Set an admin password." : "Nastavi geslo skrbnika.",
    "Can't create or write into the data directory %s" : "Ni mogoče zapisati podatkov v podatkovno mapo %s",
    "Invalid Federated Cloud ID" : "Neveljaven ID zveznega oblaka ownCloud",
    "%s shared »%s« with you" : "%s je omogočil souporabo »%s«",
    "%s via %s" : "%s prek %s",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Omogočanje souporabe %s je spodletelo, ker ozadnji program ne dopušča souporabe vrste %i.",
    "Sharing %s failed, because the file does not exist" : "Souporaba %s je spodletela, ker ta datoteka ne obstaja",
    "You are not allowed to share %s" : "Omogočanje souporabe %s brez ustreznih dovoljenj ni mogoče.",
    "Sharing %s failed, because you can not share with yourself" : "Nastavitev souporabe %s je spodletela, ker souporaba s samim sabo ni mogoča.",
    "Sharing %s failed, because the user %s does not exist" : "Nastavljanje souporabe %s je spodletelo, ker uporabnik %s ne obstaja.",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Nastavljanje souporabe %s je spodletelo, ker uporabnik %s ni član nobene skupine, v kateri je tudi uporabnik %s.",
    "Sharing %s failed, because this item is already shared with %s" : "Nastavljanje souporabe %s je spodletela, ker je ima uporabnik %s predmet že v souporabi.",
    "Sharing %s failed, because this item is already shared with user %s" : "Nastavljanje souporabe %s je spodletelo, ker je predmet z uporabnikom %s že v souporabi.",
    "Sharing %s failed, because the group %s does not exist" : "Nastavljanje souporabe %s je spodletelo, ker je skupina %s ne obstaja.",
    "Sharing %s failed, because %s is not a member of the group %s" : "Nastavljanje souporabe %s je spodletelo, ker uporabnik %s ni član skupine %s.",
    "You need to provide a password to create a public link, only protected links are allowed" : "Navesti je treba geslo za ustvarjanje javne povezave, saj so dovoljene le zaščitene.",
    "Sharing %s failed, because sharing with links is not allowed" : "Nastavljanje souporabe %s je spodletelo, ker souporaba prek povezave ni dovoljena.",
    "Not allowed to create a federated share with the same user" : "Ni dovoljeno ustvariti souporabe zveznega oblaka z istim uporabnikom",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Omogočanje souporabe %s je spodletelo, ker ni mogoče najti %s. Najverjetneje je strežnik nedosegljiv.",
    "Share type %s is not valid for %s" : "Vrsta souporabe %s za %s ni veljavna.",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Nastavljanje dovoljenj za %s je spodletelo, saj ta presegajo dovoljenja dodeljena uporabniku %s.",
    "Setting permissions for %s failed, because the item was not found" : "Nastavljanje dovoljenj za %s je spodletelo, ker predmeta ni mogoče najti.",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Ni mogoče določiti datuma preteka. Ni dovoljeno, da so mape ali datoteke, dodeljene v souporabo, v souporabi po %s.",
    "Cannot set expiration date. Expiration date is in the past" : "Ni mogoče nastaviti datuma preteka. Ta datum je že preteklost.",
    "Cannot clear expiration date. Shares are required to have an expiration date." : "Ni mogoče počistiti datuma preteka. Mape ali datoteke morajo imeti dodeljen ta parameter.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Souporaba ozadnjega programa %s mora vsebovati tudi vmesnik OCP\\Share_Backend",
    "Sharing backend %s not found" : "Ozadnjega programa %s za souporabo ni mogoče najti",
    "Sharing backend for %s not found" : "Ozadnjega programa za souporabo za %s ni mogoče najti",
    "Sharing failed, because the user %s is the original sharer" : "Nastavitev souporabe je spodletela, ker je uporabnik %s prvi omogočil souporabo.",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Nastavljanje souporabe %s je spodletelo, ker zahteve presegajo dodeljena dovoljenja za %s.",
    "Sharing %s failed, because resharing is not allowed" : "Nastavljanje souporabe %s je spodletelo, ker nadaljnje omogočanje souporabe ni dovoljeno.",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Nastavljanje souporabe %s je spodletelo, ker ozadnji program %s ne upravlja z viri.",
    "Sharing %s failed, because the file could not be found in the file cache" : "Nastavljanje souporabe %s je spodletelo, ker v predpomnilniku zahtevana datoteka ne obstaja.",
    "Cannot increase permissions of %s" : "Ni mogoče povečati dovoljen %s",
    "Files can't be shared with delete permissions" : "Souporaba datotek z nastavljenim dovoljenjem za brisanje ni mogoča",
    "Files can't be shared with create permissions" : "Souporaba datotek z nastavljenim dovoljenjem za ustvarjanje ni mogoča",
    "Expiration date is in the past" : "Datum preteka je že mimo!",
    "Cannot set expiration date more than %s days in the future" : "Datuma pretaka ni mogoče nastaviti za več kot %s dni v prihodnosti.",
    "Could not find category \"%s\"" : "Kategorije \"%s\" ni mogoče najti.",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "V uporabniškem imenu je dovoljeno uporabiti le znake: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"",
    "A valid username must be provided" : "Navedeno mora biti veljavno uporabniško ime",
    "Username contains whitespace at the beginning or at the end" : "Uporabniško ime vsebuje presledni znak na začetku ali na koncu imena.",
    "A valid password must be provided" : "Navedeno mora biti veljavno geslo",
    "The username is already being used" : "Vpisano uporabniško ime je že v uporabi",
    "Login canceled by app" : "Program je prijavo prekinil.",
    "User disabled" : "Uporabnik je onemogočen",
    "Help" : "Pomoč",
    "Settings" : "Nastavitve",
    "Users" : "Uporabniki",
    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Programa \"%s\" ni mogoče namestiti zaradi nerešenih odvisnosti: %s",
    "web services under your control" : "spletne storitve pod vašim nadzorom",
    "File is currently busy, please try again later" : "Datoteka je trenutno v uporabi. Poskusite znova kasneje.",
    "Can't read file" : "Datoteke ni mogoče prebrati.",
    "Application is not enabled" : "Program ni omogočen",
    "Authentication error" : "Napaka overjanja",
    "Token expired. Please reload page." : "Žeton je potekel. Stran je treba ponovno naložiti.",
    "Unknown user" : "Neznan uporabnik",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Ni nameščenih programnikov podatkovnih zbirk (sqlite, mysql, ali postgresql).",
    "Cannot write into \"config\" directory" : "Mapa 'config' nima nastavljenih ustreznih dovoljenj za pisanje!",
    "Cannot write into \"apps\" directory" : "Mapa \"apps\" nima nastavljenih ustreznih dovoljenj za pisanje!",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Napako je mogoče odpraviti z dodelitvijo dovoljenja spletnemu strežniku %s za pisanje v mapo programov %s, ali pa z onemogočanjem nameščanja programov v nastavitveni datoteki.",
    "Cannot create \"data\" directory" : "Ni mogoče ustvariti \"podatkovne\" mape",
    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "To se običajno lahko odpravi z <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">dodelitvijo dovoljenja spletnemu strežniku za pisanje v korenski imenik</a>.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Dovoljenja je mogoče odpraviti z %sdodelitvijo dovoljenja spletnemu strežniku za pisanje korensko mapo%s.",
    "Setting locale to %s failed" : "Nastavljanje jezikovnih določil na %s je spodletelo.",
    "Please install one of these locales on your system and restart your webserver." : "Namestiti je treba podporo za vsaj eno od navedenih jezikovnih določil v sistemu in nato ponovno zagnati spletni strežnik.",
    "Please ask your server administrator to install the module." : "Obvestite skrbnika strežnika, da je treba namestiti manjkajoč modul.",
    "PHP module %s not installed." : "Modul PHP %s ni nameščen.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Nastavitev PHP \"%s\" ni nastavljena na \"%s\".",
    "Adjusting this setting in php.ini will make ownCloud run again" : "Prilagoditev te nastavitve v datoteki php.ini lahko omogoči delovanje oblaka ownCloud.",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "parameter mbstring.func_overload je nastavljen na \"%s\" namesto pričakovane vrednosti \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Da bi odpravili to težavo, nastavite <code>mbstring.func_overload</code> na <code>0</code> v datoteki php.ini.",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Zahtevana je knjižnica libxml2 2.7.0. Trenutno je nameščena različica %s.",
    "To fix this issue update your libxml2 version and restart your web server." : "Za rešitev te težave je treba posodobiti knjižnico libxml2 in nato ponovno zagnati spletni strežnik.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Nastavitve PHP določajo, da so medvrstični bloki besedila odrezani. Ta nastavitev lahko povzroči, da nekateri osnovni moduli ne bodo dosegljivi.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Napako je najverjetneje povzročil predpomnilniški program oziroma pospeševalnik, kot sta Zend OPcache ali eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Ali so bili moduli PHP nameščeni, pa so še vedno označeni kot manjkajoči?",
    "Please ask your server administrator to restart the web server." : "Obvestite skrbnika strežnika, da je treba ponovno zagnati spletni strežnik.",
    "PostgreSQL >= 9 required" : "Zahtevana je različica PostgreSQL >= 9.",
    "Please upgrade your database version" : "Posodobite različico podatkovne zbirke.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Spremenite dovoljenja mape na 0770 in s tem onemogočite branje vsebine drugim uporabnikom.",
    "Your Data directory is readable by other users" : "Podatkovna mapa ima določena dovoljenja za branje skupine.",
    "Your Data directory must be an absolute path" : "Podatkovna mapa mora imeti navedeno celotno pot.",
    "Check the value of \"datadirectory\" in your configuration" : "Preverite nastavitev \"datadirectory\"",
    "Your Data directory  is invalid" : "Podatkovna mapa ni veljavna.",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Preverite, ali je v korenu podatkovne mape datoteka \".ocdata\".",
    "Could not obtain lock type %d on \"%s\"." : "Ni mogoče pridobiti zaklepa %d na \"%s\".",
    "Storage unauthorized. %s" : "Dostop do shrambe ni overjen. %s",
    "Storage incomplete configuration. %s" : "Nepopolna nastavitev shrambe. %s",
    "Storage connection error. %s" : "Napaka povezave do shrambe. %s",
    "Storage is temporarily not available" : "Shramba trenutno ni na voljo",
    "Storage connection timeout. %s" : "Povezava do shrambe je časovno potekla. %s",
    "A safe home for all your data" : "Varno mesto za vse pomembne podatke",
    "User Authentication" : "Overitev uporabnika",
    "File cannot be read" : "Datoteke ni mogoče prebrati",
    "Imprint" : "Natis",
    "__language_name__" : "Slovenščina"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
